==> blesta-5.10.2.zip: blesta/components/modules/direct_admin/language/cs_cz/direct_admin.php <==
<?php
/**
 * Direct Admin
 *
 * @package blesta
 * @subpackage blesta.language.cs_cz
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['DirectAdmin.tab_client_stats.no_results'] = 'Statistické informace nejsou v současné době k dispozici.';
$lang['DirectAdmin.tab_client_stats.info_heading.value'] = 'Hodnota';
$lang['DirectAdmin.tab_client_stats.info_heading.field'] = 'Pole';
$lang['DirectAdmin.tab_client_stats.info_title'] = 'Informace';
$lang['DirectAdmin.tab_client_stats'] = 'Statistiky';
$lang['DirectAdmin.edit_row.add_btn'] = 'Upravit server';
$lang['DirectAdmin.edit_row.notes_title'] = 'Poznámky';
$lang['DirectAdmin.edit_row.remove_name_server'] = 'Odstranění stránky';
$lang['DirectAdmin.edit_row.name_server_host_col'] = 'Hostitelské jméno';
$lang['DirectAdmin.edit_row.name_server_col'] = 'Jmenný server';
$lang['DirectAdmin.edit_row.name_server_btn'] = 'Přidání dalšího jmenného serveru';
$lang['DirectAdmin.edit_row.name_servers_title'] = 'Jmenné servery';
$lang['DirectAdmin.edit_row.basic_title'] = 'Základní nastavení';
$lang['DirectAdmin.edit_row.box_title'] = 'Upravit server DirectAdmin';
$lang['DirectAdmin.add_row.add_btn'] = 'Přidat server';
$lang['DirectAdmin.add_row.notes_title'] = 'Poznámky';
$lang['DirectAdmin.add_row.remove_name_server'] = 'Odstranění stránky';
$lang['DirectAdmin.add_row.name_server_host_col'] = 'Hostitelské jméno';
$lang['DirectAdmin.add_row.name_server_col'] = 'Jmenný server';
$lang['DirectAdmin.add_row.name_server_btn'] = 'Přidání dalšího jmenného serveru';
$lang['DirectAdmin.add_row.name_servers_title'] = 'Jmenné servery';
$lang['DirectAdmin.add_row.basic_title'] = 'Základní nastavení';
$lang['DirectAdmin.add_row.box_title'] = 'Přidání serveru DirectAdmin';
$lang['DirectAdmin.row_meta.name_server'] = 'Name server %1$s';
$lang['DirectAdmin.row_meta.account_limit'] = 'Limit účtu';
$lang['DirectAdmin.row_meta.use_ssl'] = 'Při připojování k rozhraní API používejte protokol SSL (doporučeno).';
$lang['DirectAdmin.row_meta.password'] = 'Heslo';
$lang['DirectAdmin.row_meta.user_name'] = 'Uživatelské jméno';
$lang['DirectAdmin.row_meta.default_port'] = '2222';
$lang['DirectAdmin.row_meta.port'] = 'Přístav';
$lang['DirectAdmin.row_meta.host_name'] = 'Název hostitele';
$lang['DirectAdmin.row_meta.server_name'] = 'Označení serveru';
$lang['DirectAdmin.manage.module_groups.confirm_delete'] = 'Opravdu chcete tuto skupinu serverů odstranit?';
$lang['DirectAdmin.manage.module_rows.confirm_delete'] = 'Opravdu chcete tento server odstranit?';
$lang['DirectAdmin.manage.module_groups.delete'] = 'Odstranit';
$lang['DirectAdmin.manage.module_rows.delete'] = 'Odstranit';
$lang['DirectAdmin.manage.module_groups.edit'] = 'Upravit';
$lang['DirectAdmin.manage.module_rows.edit'] = 'Upravit';
$lang['DirectAdmin.manage.module_rows.count'] = '%1$s / %2$s';
$lang['DirectAdmin.manage.module_groups_heading.options'] = 'Možnosti';
$lang['DirectAdmin.manage.module_groups_heading.servers'] = 'Počet serverů';
$lang['DirectAdmin.manage.module_groups_heading.name'] = 'Název skupiny';
$lang['DirectAdmin.manage.module_rows_heading.options'] = 'Možnosti';
$lang['DirectAdmin.manage.module_rows_heading.accounts'] = 'Účty';
$lang['DirectAdmin.manage.module_rows_heading.host_name'] = 'Název hostitele';
$lang['DirectAdmin.manage.module_rows_heading.name'] = 'Označení serveru';
$lang['DirectAdmin.manage.module_groups_title'] = 'Skupiny serverů';
$lang['DirectAdmin.manage.module_rows_title'] = 'Servery';
$lang['DirectAdmin.add_module_group'] = 'Přidání skupiny serverů';
$lang['DirectAdmin.add_module_row'] = 'Přidat server';
$lang['DirectAdmin.package_fields.ip_assign'] = 'Přiřazení';
$lang['DirectAdmin.package_fields.ip_shared'] = 'Sdílené stránky';
$lang['DirectAdmin.package_fields.ip'] = 'IP adresa';
$lang['DirectAdmin.package_fields.package'] = 'Balíček DirectAdmin';
$lang['DirectAdmin.package_fields.type_reseller'] = 'Prodejce';
$lang['DirectAdmin.package_fields.type_user'] = 'Uživatel';
$lang['DirectAdmin.package_fields.type'] = 'Typ účtu';
$lang['DirectAdmin.service_info.option_login'] = 'Přihlášení';
$lang['DirectAdmin.service_info.options'] = 'Možnosti';
$lang['DirectAdmin.service_info.server'] = 'Server';
$lang['DirectAdmin.service_info.password'] = 'Heslo';
$lang['DirectAdmin.service_info.username'] = 'Uživatelské jméno';
$lang['DirectAdmin.tab_client_actions.text_generate_password'] = 'Generování hesla';
$lang['DirectAdmin.tab_client_actions.field_password_submit'] = 'Aktualizace hesla';
$lang['DirectAdmin.tab_client_actions.field_direct_admin_confirm_password'] = 'Potvrzení hesla';
$lang['DirectAdmin.tab_client_actions.field_direct_admin_password'] = 'Heslo';
$lang['DirectAdmin.tab_client_actions.change_password'] = 'Změna hesla';
$lang['DirectAdmin.service_field.text_generate_password'] = 'Generování hesla';
$lang['DirectAdmin.service_field.email'] = 'E-mail';
$lang['DirectAdmin.service_field.password'] = 'Heslo';
$lang['DirectAdmin.service_field.username'] = 'Uživatelské jméno';
$lang['DirectAdmin.service_field.domain'] = 'Doména';
$lang['DirectAdmin.server_groups.no_results'] = 'Neexistují žádné skupiny serverů.';
$lang['DirectAdmin.servers.no_results'] = 'Neexistují žádné servery.';
$lang['DirectAdmin.order_options.roundrobin'] = 'Rovnoměrné rozdělení mezi servery';
$lang['DirectAdmin.order_options.first'] = 'První nenaplněný server';
$lang['DirectAdmin.tab_client_actions'] = 'Akce';
$lang['DirectAdmin.tab_stats'] = 'Statistiky';
$lang['DirectAdmin.module_group'] = 'Skupina serverů';
$lang['DirectAdmin.module_row_plural'] = 'Servery';
$lang['DirectAdmin.module_row'] = 'Server';
$lang['DirectAdmin.description'] = 'DirectAdmin je grafický webový ovládací panel webhostingu určený pro snadnější správu webových stránek.';
$lang['DirectAdmin.name'] = 'DirectAdmin';
$lang['DirectAdmin.!error.change_package.type'] = 'Modul nepodporuje změnu mezi uživatelskými a prodejními balíčky.';
$lang['DirectAdmin.!error.direct_admin_email.format'] = 'Zadejte prosím platnou e-mailovou adresu.';
$lang['DirectAdmin.!error.direct_admin_password.matches'] = 'Heslo a potvrzovací heslo se neshodují.';
$lang['DirectAdmin.!error.direct_admin_password.format'] = 'Ujistěte se, že heslo obsahuje následující údaje: alespoň 12 znaků, alespoň 1 velký znak A-Z, alespoň 1 malý znak a-z, alespoň 1 číslo 0-9 a alespoň 1 speciální znak ze sady: !"#$%&\'()*+,-./:;<=>?@[]^_` {|}';
$lang['DirectAdmin.!error.direct_admin_username.length'] = 'Uživatelské jméno musí mít délku 4 až 8 znaků.';
$lang['DirectAdmin.!error.direct_admin_username.format'] = 'Uživatelské jméno může obsahovat pouze alfanumerické znaky.';
$lang['DirectAdmin.!error.direct_admin_domain.format'] = 'Zadejte prosím platný název domény ve tvaru: domain.com';
$lang['DirectAdmin.!error.meta[ip].empty'] = 'Je vyžadována IP adresa.';
$lang['DirectAdmin.!error.meta[package].empty'] = 'Je vyžadován balíček DirectAdmin.';
$lang['DirectAdmin.!error.meta[type].format'] = 'Typ účtu musí být uživatelský nebo prodejní.';
$lang['DirectAdmin.!error.api.internal'] = 'Došlo k interní chybě nebo server na požadavek neodpověděl.';
$lang['DirectAdmin.!error.name_servers.count'] = 'Je třeba definovat alespoň 2 jmenné servery.';
$lang['DirectAdmin.!error.name_servers.valid'] = 'Jeden nebo více zadaných názvových serverů jsou neplatné.';
$lang['DirectAdmin.!error.account_limit.valid'] = 'Limit účtu musí zůstat prázdný (pro neomezený počet účtů) nebo musí být nastaven na nějakou celočíselnou hodnotu.';
$lang['DirectAdmin.!error.use_ssl.format'] = 'Použít SSL musí být true nebo false.';
$lang['DirectAdmin.!error.password.format'] = 'Musíte zadat heslo.';
$lang['DirectAdmin.!error.user_name.empty'] = 'Musíte zadat uživatelské jméno.';
$lang['DirectAdmin.!error.port.format'] = 'Port musí být číslo.';
$lang['DirectAdmin.!error.host_name.format'] = 'Název hostitele se zdá být neplatný.';
$lang['DirectAdmin.!error.server_name.empty'] = 'Je třeba zadat označení serveru.';

==> blesta-5.11.4.zip: blesta/components/modules/direct_admin/language/cs_cz/direct_admin.php <==
<?php
/**
 * Direct Admin
 *
 * @package blesta
 * @subpackage blesta.language.cs_cz
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['DirectAdmin.tab_client_stats.no_results'] = 'Statistické informace nejsou v současné době k dispozici.';
$lang['DirectAdmin.tab_client_stats.info_heading.value'] = 'Hodnota';
$lang['DirectAdmin.tab_client_stats.info_heading.field'] = 'Pole';
$lang['DirectAdmin.tab_client_stats.info_title'] = 'Informace';
$lang['DirectAdmin.tab_client_stats'] = 'Statistiky';
$lang['DirectAdmin.edit_row.add_btn'] = 'Upravit server';
$lang['DirectAdmin.edit_row.notes_title'] = 'Poznámky';
$lang['DirectAdmin.edit_row.remove_name_server'] = 'Odstranění stránky';
$lang['DirectAdmin.edit_row.name_server_host_col'] = 'Hostitelské jméno';
$lang['DirectAdmin.edit_row.name_server_col'] = 'Jmenný server';
$lang['DirectAdmin.edit_row.name_server_btn'] = 'Přidání dalšího jmenného serveru';
$lang['DirectAdmin.edit_row.name_servers_title'] = 'Jmenné servery';
$lang['DirectAdmin.edit_row.basic_title'] = 'Základní nastavení';
$lang['DirectAdmin.edit_row.box_title'] = 'Upravit server DirectAdmin';
$lang['DirectAdmin.add_row.add_btn'] = 'Přidat server';
$lang['DirectAdmin.add_row.notes_title'] = 'Poznámky';
$lang['DirectAdmin.add_row.remove_name_server'] = 'Odstranění stránky';
$lang['DirectAdmin.add_row.name_server_host_col'] = 'Hostitelské jméno';
$lang['DirectAdmin.add_row.name_server_col'] = 'Jmenný server';
$lang['DirectAdmin.add_row.name_server_btn'] = 'Přidání dalšího jmenného serveru';
$lang['DirectAdmin.add_row.name_servers_title'] = 'Jmenné servery';
$lang['DirectAdmin.add_row.basic_title'] = 'Základní nastavení';
$lang['DirectAdmin.add_row.box_title'] = 'Přidání serveru DirectAdmin';
$lang['DirectAdmin.row_meta.name_server'] = 'Name server %1$s';
$lang['DirectAdmin.row_meta.account_limit'] = 'Limit účtu';
$lang['DirectAdmin.row_meta.use_ssl'] = 'Při připojování k rozhraní API používejte protokol SSL (doporučeno).';
$lang['DirectAdmin.row_meta.password'] = 'Heslo';
$lang['DirectAdmin.row_meta.user_name'] = 'Uživatelské jméno';
$lang['DirectAdmin.row_meta.default_port'] = '2222';
$lang['DirectAdmin.row_meta.port'] = 'Přístav';
$lang['DirectAdmin.row_meta.host_name'] = 'Název hostitele';
$lang['DirectAdmin.row_meta.server_name'] = 'Označení serveru';
$lang['DirectAdmin.manage.module_groups.confirm_delete'] = 'Opravdu chcete tuto skupinu serverů odstranit?';
$lang['DirectAdmin.manage.module_rows.confirm_delete'] = 'Opravdu chcete tento server odstranit?';
$lang['DirectAdmin.manage.module_groups.delete'] = 'Odstranit';
$lang['DirectAdmin.manage.module_rows.delete'] = 'Odstranit';
$lang['DirectAdmin.manage.module_groups.edit'] = 'Upravit';
$lang['DirectAdmin.manage.module_rows.edit'] = 'Upravit';
$lang['DirectAdmin.manage.module_rows.count'] = '%1$s / %2$s';
$lang['DirectAdmin.manage.module_groups_heading.options'] = 'Možnosti';
$lang['DirectAdmin.manage.module_groups_heading.servers'] = 'Počet serverů';
$lang['DirectAdmin.manage.module_groups_heading.name'] = 'Název skupiny';
$lang['DirectAdmin.manage.module_rows_heading.options'] = 'Možnosti';
$lang['DirectAdmin.manage.module_rows_heading.accounts'] = 'Účty';
$lang['DirectAdmin.manage.module_rows_heading.host_name'] = 'Název hostitele';
$lang['DirectAdmin.manage.module_rows_heading.name'] = 'Označení serveru';
$lang['DirectAdmin.manage.module_groups_title'] = 'Skupiny serverů';
$lang['DirectAdmin.manage.module_rows_title'] = 'Servery';
$lang['DirectAdmin.add_module_group'] = 'Přidání skupiny serverů';
$lang['DirectAdmin.add_module_row'] = 'Přidat server';
$lang['DirectAdmin.package_fields.ip_assign'] = 'Přiřazení';
$lang['DirectAdmin.package_fields.ip_shared'] = 'Sdílené stránky';
$lang['DirectAdmin.package_fields.ip'] = 'IP adresa';
$lang['DirectAdmin.package_fields.package'] = 'Balíček DirectAdmin';
$lang['DirectAdmin.package_fields.type_reseller'] = 'Prodejce';
$lang['DirectAdmin.package_fields.type_user'] = 'Uživatel';
$lang['DirectAdmin.package_fields.type'] = 'Typ účtu';
$lang['DirectAdmin.service_info.option_login'] = 'Přihlášení';
$lang['DirectAdmin.service_info.options'] = 'Možnosti';
$lang['DirectAdmin.service_info.server'] = 'Server';
$lang['DirectAdmin.service_info.password'] = 'Heslo';
$lang['DirectAdmin.service_info.username'] = 'Uživatelské jméno';
$lang['DirectAdmin.tab_client_actions.text_generate_password'] = 'Generování hesla';
$lang['DirectAdmin.tab_client_actions.field_password_submit'] = 'Aktualizace hesla';
$lang['DirectAdmin.tab_client_actions.field_direct_admin_confirm_password'] = 'Potvrzení hesla';
$lang['DirectAdmin.tab_client_actions.field_direct_admin_password'] = 'Heslo';
$lang['DirectAdmin.tab_client_actions.change_password'] = 'Změna hesla';
$lang['DirectAdmin.service_field.text_generate_password'] = 'Generování hesla';
$lang['DirectAdmin.service_field.email'] = 'E-mail';
$lang['DirectAdmin.service_field.password'] = 'Heslo';
$lang['DirectAdmin.service_field.username'] = 'Uživatelské jméno';
$lang['DirectAdmin.service_field.domain'] = 'Doména';
$lang['DirectAdmin.server_groups.no_results'] = 'Neexistují žádné skupiny serverů.';
$lang['DirectAdmin.servers.no_results'] = 'Neexistují žádné servery.';
$lang['DirectAdmin.order_options.roundrobin'] = 'Rovnoměrné rozdělení mezi servery';
$lang['DirectAdmin.order_options.first'] = 'První nenaplněný server';
$lang['DirectAdmin.tab_client_actions'] = 'Akce';
$lang['DirectAdmin.tab_stats'] = 'Statistiky';
$lang['DirectAdmin.module_group'] = 'Skupina serverů';
$lang['DirectAdmin.module_row_plural'] = 'Servery';
$lang['DirectAdmin.module_row'] = 'Server';
$lang['DirectAdmin.description'] = 'DirectAdmin je grafický webový ovládací panel webhostingu určený pro snadnější správu webových stránek.';
$lang['DirectAdmin.name'] = 'DirectAdmin';
$lang['DirectAdmin.!error.change_package.type'] = 'Modul nepodporuje změnu mezi uživatelskými a prodejními balíčky.';
$lang['DirectAdmin.!error.direct_admin_email.format'] = 'Zadejte prosím platnou e-mailovou adresu.';
$lang['DirectAdmin.!error.direct_admin_password.matches'] = 'Heslo a potvrzovací heslo se neshodují.';
$lang['DirectAdmin.!error.direct_admin_password.format'] = 'Ujistěte se, že heslo obsahuje následující údaje: alespoň 12 znaků, alespoň 1 velký znak A-Z, alespoň 1 malý znak a-z, alespoň 1 číslo 0-9 a alespoň 1 speciální znak ze sady: !"#$%&\'()*+,-./:;<=>?@[]^_` {|}';
$lang['DirectAdmin.!error.direct_admin_username.length'] = 'Uživatelské jméno musí mít délku 4 až 8 znaků.';
$lang['DirectAdmin.!error.direct_admin_username.format'] = 'Uživatelské jméno může obsahovat pouze alfanumerické znaky.';
$lang['DirectAdmin.!error.direct_admin_domain.format'] = 'Zadejte prosím platný název domény ve tvaru: domain.com';
$lang['DirectAdmin.!error.meta[ip].empty'] = 'Je vyžadována IP adresa.';
$lang['DirectAdmin.!error.meta[package].empty'] = 'Je vyžadován balíček DirectAdmin.';
$lang['DirectAdmin.!error.meta[type].format'] = 'Typ účtu musí být uživatelský nebo prodejní.';
$lang['DirectAdmin.!error.api.internal'] = 'Došlo k interní chybě nebo server na požadavek neodpověděl.';
$lang['DirectAdmin.!error.name_servers.count'] = 'Je třeba definovat alespoň 2 jmenné servery.';
$lang['DirectAdmin.!error.name_servers.valid'] = 'Jeden nebo více zadaných názvových serverů jsou neplatné.';
$lang['DirectAdmin.!error.account_limit.valid'] = 'Limit účtu musí zůstat prázdný (pro neomezený počet účtů) nebo musí být nastaven na nějakou celočíselnou hodnotu.';
$lang['DirectAdmin.!error.use_ssl.format'] = 'Použít SSL musí být true nebo false.';
$lang['DirectAdmin.!error.password.format'] = 'Musíte zadat heslo.';
$lang['DirectAdmin.!error.user_name.empty'] = 'Musíte zadat uživatelské jméno.';
$lang['DirectAdmin.!error.port.format'] = 'Port musí být číslo.';
$lang['DirectAdmin.!error.host_name.format'] = 'Název hostitele se zdá být neplatný.';
$lang['DirectAdmin.!error.server_name.empty'] = 'Je třeba zadat označení serveru.';
$lang['DirectAdmin.row_meta.ip_address'] = 'IP adresa';
$lang['DirectAdmin.!error.ip_address.format'] = 'IP adresa se zdá být neplatná.';
